def create_project(project_name = 'DataProject', **keywords):
    """
    Creates the project and creates a skelton directory
    structure
    
    Params:
      project_name: A string that represents the name of the project
    
      keywords:
        git: create a git repo? type bool, default false
        full_structure: create a full strucutre? type bool, default false
        packages: define a list of packages to always load, type list, default empty
        logging: automatically start logging. type bool, default false
    """

    import os
    from json import dump

    os.mkdir(project_name)
    os.chdir(project_name)

    #Set up config
    config = {}

    config['git'] = keywords.get('git', False)
    config['full_structure'] = keywords.get('full_structure', False)
    config['packages'] = keywords.get('package', [])
    config['logging'] = keywords.get('logging', False)
    config['name'] = project_name


    #Create folder strucutre
    if config['full_structure']:
        folders = ['data', 'diagnostics', 'doc', 'graphs', \
                    'lib', 'reports', 'profiling', 'tests', 'munge']
    else:
        folders = ['data', 'lib', 'munge']

    map(os.mkdir, folders)

    #Create files
    os.system('touch README.txt')
    #os.system('touch __init__.py')
    #os.system('touch data/__init__.py')
    #os.system('touch lib/__init__.py')
    #os.system('touch munge/__init__.py')

    #modify python path, put the project on it, removed when project destoryed
    #get join to work properly
    #os.environ['PYTHONPATH'] = \
            #os.environ['PYTHONPATH'] + '/:' +  os.getcwd()
    #os.system('export PYTHONPATH=$PYTHONPATH/:%s' % os.getcwd())
    #print 'export PYTHONPATH=$PYTHONPATH:%s' % os.getcwd()

    #Creatgit repo
    if config['git']:
        os.system('git init --quiet')

    #Dump into config file
    with open('.config.json', mode='w') as f:
        dump(config, f)



def load_project():
    """
    Loads the project into the workspace
    
    Does three things currently
      1. Recursively loads you csv files into data frames
         prepending the folder if not in data
      2. Runs files in the munge folder.  These are
         preprocessing scripts
      3. Imports files in lib
      4. Starts Logging
    
    """
    from os import listdir, chdir, walk, getcwd
    from os.path import join, split
    from pandas import read_csv
    from json import load
    
    shell = get_ipython()

    with open('.config.json', 'r') as f:
        config = load(f)

    filename = lambda x: x.split('.')[0]

    vars_to_push = {}
    for directory, _, datafiles in walk('data', topdown=False):
        for datafile in datafiles:
            if directory == 'data':
                var_name = filename(datafile)
                read_location = join('data', datafile)
                vars_to_push[var_name] = read_csv(read_location)
            else:
                var_name = split(directory)[-1] + '_' + filename(datafile)
                read_location = join(directory, datafile)
                vars_to_push[var_name] = read_csv(read_location)
    shell.push(vars_to_push)

    mungefiles = listdir('munge')
    for mungefile in mungefiles:
        shell.magic('run -i munge/%s' % mungefile)

    libfiles = listdir('lib')
    libs_to_push = {}
    chdir('lib')
    for libfile in libfiles:
        mod = filename(libfile)
        libs_to_push[mod] = __import__(filename(libfile))
    shell.push(libs_to_push)
    chdir('..')

    packages = config['packages']
    for package in packages:
        shell.runcode('import %s' % package)

    if config['logging']:
      shell.magic_logstart(getcwd().split('/')[-1] \
          + '_logging.py append')



from distutils.core import setup

setup(
    name='Gloo',
    version='0.0.1',
    author='Trent Hauck',
    author_email='trent@trenthauck.com',
    packages=['gloo'],
    scripts=[],
    url='http://pypi.python.org/pypi/Gloo/',
    license='LICENSE.txt',
    description='Project management for data analysis projects.',
    #install_requires=[],
    long_description=open('README.txt').read()
)
